@@ -8,7 +8,7 @@ class Webhook:
     name: str
     url: str
     secret: str
-    status: str
+    enabled: bool
     events: List[str]
     successfully_sent: int
     failed_sent: int
